@@ -119,14 +119,18 @@ class HeaderParamType(click.ParamType):
     "--custom-header",
     type=HeaderParamType(),
     multiple=True,
-    help="Custom header to add to proxied requests. Use same option for multiple headers (--custom-header k1:v1 --custom-header k2:v2) (default: [])",
+    help=(
+        "Custom header to add to proxied requests. Use same option for multiple headers "
+        "(--custom-header k1:v1 --custom-header k2:v2) (default: [])"
+    ),
 )
 @click.option("--insecure", help="Disable SSL cert verification")
 @click.option("--host-routing", help="Use host routing (host as first level of path)")
 @click.option(
     "--log-level",
     type=click.Choice(
-        [logging.getLevelName(i) for i in (logging.DEBUG, logging.INFO, logging.WARNING, logging.ERROR)]
+        [logging.getLevelName(i) for i in (logging.DEBUG, logging.INFO, logging.WARNING, logging.ERROR)],
+        case_sensitive=False,
     ),
     help='Log level (debug, info, warning, error) (default: "info")',
 )
@@ -374,7 +378,7 @@ def main(**args):
 
     try:
         IOLoop.current().start()
-    except Exception as err:
+    except Exception:
         if pid_file:  # Cleanup PID file
             log.debug(f"Removing {pid_file}")
             os.remove(pid_file)
